======
HPSSPy
======

.. image:: https://img.shields.io/pypi/l/hpsspy.svg
    :target: https://pypi.python.org/pypi/hpsspy
    :alt: License

.. image:: https://img.shields.io/pypi/v/hpsspy.svg
    :target: https://pypi.python.org/pypi/hpsspy
    :alt: PyPI Badge

.. image:: https://img.shields.io/pypi/dm/hpsspy.svg
    :target: https://pypi.python.org/pypi/hpsspy
    :alt: PyPI Downloads

.. image:: https://img.shields.io/travis/weaverba137/hpsspy.svg
    :target: https://travis-ci.org/weaverba137/hpsspy
    :alt: Travis Build Status

.. image:: https://coveralls.io/repos/github/weaverba137/hpsspy/badge.svg
    :target: https://coveralls.io/github/weaverba137/hpsspy?branch=master
    :alt: Test Coverage Status

.. image:: https://readthedocs.org/projects/hpsspy/badge/
    :target: http://hpsspy.readthedocs.io/en/latest/
    :alt: Documentation Status

Overview
--------

HPSSPy is a Python_ package for interacting with the HPSS_ tape storage
system at NERSC_.  It is currently being developed on GitHub_.

.. _Python: http://python.org
.. _HPSS: http://www.nersc.gov/systems/hpss-data-archive/
.. _NERSC: http://www.nersc.gov
.. _GitHub: https://github.com/weaverba137/hpsspy

Requirements
------------

HPSSPy assumes that the HPSS utilities `hsi and htar`_ are installed.  You may
need a NERSC account to download and install these utilities.

.. _`hsi and htar`: https://www.nersc.gov/users/data-and-file-systems/hpss/storing-and-retrieving-data/software-downloads/

License
-------

HPSSPy is free software licensed under a 3-clause BSD-style license. For details see
the ``LICENSE.rst`` file.
